@@ -91,13 +91,13 @@ class HGit:
         Either hop_main or hop_<release>.
         """
         rel_branch = f'hop_{release_s}'
-        if str(self.branch) == 'hop_main':
+        if str(self.branch) == 'hop_main' and rel_branch != 'hop_main':
             # creates the new branch
             print(f'NEW branch hop_{release_s}')
             self.repo.create_head(rel_branch)
             self.repo.git.checkout(rel_branch)
         elif str(self.branch) == rel_branch:
-            print(f'OK! sur {rel_branch}')
+            print(f'OK! on {rel_branch}')
         else:
             sys.stderr.write(f'PB! pas sur la bonne branche!\n')
             sys.exit(1)
